This module provides vectorized functions for clinical data analysis using the dplyr and tidyr ecosystems. It replaces legacy row-wise loops with efficient group-by operations.
This module provides vectorized functions for clinical data analysis using the dplyr and tidyr ecosystems. It replaces legacy row-wise loops with efficient group-by operations.