This module provides efficient conversion of analysis results to flextable and optimized assembly of Word documents using the officer package.
This module provides efficient conversion of analysis results to flextable and optimized assembly of Word documents using the officer package.